SystemOrganization addCategory: #ConfigurationOfXMLParser!

Object subclass: #ConfigurationOfXMLParser
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfXMLParser'!

!ConfigurationOfXMLParser commentStamp: 'monty 12/16/2014 16:19' prior: 0!
(ConfigurationOfXMLParser project version: #stable) load: 'default'!

!ConfigurationOfXMLParser class methodsFor: 'private' stamp: 'DaleHenrichs 2/7/2010 09:39'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfXMLParser class methodsFor: 'catalog' stamp: 'monty 12/13/2013 05:39'!
catalogChangeLog

^ '

- Version 1.3 - 2013-11-22 Monty''s Enhancements
These updates add validation against internal and external DTDs, proper replacement of general and parameter entites, customizable resolution of external parsed entities using Zinc and FileSystem, awareness of notations and unparsed entities, preservation of the internal DTD subset by the DOM parser (so printing a parsed doc with a DTD will produce approximately what was input), line numbers reporting in error messages, and better well-formed and validity constraints.

I had to largely rewrite the tokenizer to make everything work, but I followed the spec closely, and it is about the same speed as long as there is no DTD to validate against.

[[[ 
	(ConfigurationOfXMLParser project version: ''1.3'') load
]]]


- Version 1.2- 2013-04-30 Removing dependency on XMLWriter.

[[[ 
	(ConfigurationOfXMLParser project version: ''1.2'') load
]]]


'! !

!ConfigurationOfXMLParser class methodsFor: 'catalog' stamp: 'monty 3/13/2015 14:41'!
catalogDescription

	^ 'XMLParser provides validating SAX and DOM parsers for well-formed XML documents on Pharo, Squeak, and Gemstone. It also provides a DOM API for manipulating documents, namespace support, and an optional XMLWriter for writing documents. Validation and namespace checking are enabled by default, but not resolution of external entities.'! !

!ConfigurationOfXMLParser class methodsFor: 'catalog' stamp: 'monty 4/13/2015 12:33'!
catalogKeyClassesAndExample

^ 'The main classes are ==SAXHandler==, ==XMLDOMParser==, and ==XMLNode== and its subclasses. Read the class comments for more information.

Validation and namespace checking are enabled by default, but not resolution of external entities.

Examples
[[[ 
	| doc |
	"Get all article titles from the content of the <title> child of each <entry>:"
	((doc := (XMLDOMParser parseURL: ''http://pharo.org/news/atom.xml''))
		allElementsNamed: ''entry'')
			collect: [:each | (each elementAt: ''title'') contentString].

	"Get feed title from first <title> anywhere in the doc:"
	(doc findElementNamed: ''title'') contentString.
	
	"Get all article links:"
	(doc allElementsNamed: ''entry'') collect: [:each |
		(each elementAt: ''link'') attributeAt: ''href'' ].
]]]
'! !

!ConfigurationOfXMLParser class methodsFor: 'catalog' stamp: 'monty 4/7/2015 00:25'!
catalogKeywords

	^ #( XML DOM SAX DTD HTML XHTML parser validation web markup document )
					
! !

!ConfigurationOfXMLParser class methodsFor: 'private' stamp: 'DaleHenrichs 2/7/2010 09:39'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfXMLParser class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 2/7/2010 09:39'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfXMLParser class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 2/7/2010 09:39'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfXMLParser class methodsFor: 'loading' stamp: 'JAAyer 11/20/2010 08:31'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfXMLParser class methodsFor: 'loading' stamp: 'JAAyer 11/20/2010 08:32'!
loadDefault
	"self loadDefault"

	^ self loadMostRecentCoreWithTests! !

!ConfigurationOfXMLParser class methodsFor: 'loading' stamp: 'JAAyer 11/20/2010 08:32'!
loadMostRecentCoreWithTests
	^self project lastVersion load: #('Core' 'Tests')! !

!ConfigurationOfXMLParser class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 2/7/2010 09:39'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfXMLParser class methodsFor: 'accessing' stamp: 'DaleHenrichs 2/7/2010 09:39'!
project

	^self new project! !

!ConfigurationOfXMLParser class methodsFor: 'unloading Metacello' stamp: 'DaleHenrichs 2/7/2010 09:39'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 4/18/2015 04:34'!
baseline10: spec
	<version: '1.0-baseline'>

	"default baseline inherited by others, describes basic dependencies.
	other baselines that inherit choose concrete versions of projects
	that need it while for the rest loading #stable is enough"
	spec
		for: #common
		do: [ 
			spec
				blessing: #baseline;
				description: 'Migrated to SmalltalkHub';
				author: 'StephaneDucasse';
				timestamp: '04/30/2013';
				repository: 'http://www.smalltalkhub.com/mc/PharoExtras/XMLParser/main'.

			"other baselines choose concrete versions because this package changes
			with XMLParser to be backwards incompatible"
			spec
				project: 'XMLWriter'
				with: [
					spec 
						className: 'ConfigurationOfXMLWriter';
						versionString: #stable;
						loads: #('default'); 
						repository: 'http://www.smalltalkhub.com/mc/PharoExtras/XMLWriter/main'.].
			spec
				project: 'BitmapCharacterSet'
				with: [
					spec 
						className: 'ConfigurationOfBitmapCharacterSet';
						versionString: #stable;
						loads: #('Core'); 
						repository: 'http://www.smalltalkhub.com/mc/PharoExtras/BitmapCharacterSet/main'.].

			"#stable is fine, the public API doesn't change to backwards incompatible"
			spec
				project: 'OrderPreservingDictionary'
				with: [
					spec 
						className: 'ConfigurationOfOrderPreservingDictionary';
						versionString: #stable; 
						loads: #('Core'); 
						repository: 'http://smalltalkhub.com/mc/PharoExtras/OrderPreservingDictionary/main'].	

			spec 
				package: 'XML-Parser' 
				with: [spec requires: #('BitmapCharacterSet' 'OrderPreservingDictionary')].
			spec
				package: 'XML-Tests-Parser'
				with: [ spec requires: #('XML-Parser' 'XMLWriter') ].
			
			spec
				group: 'default' with: #('Core' 'Tests');
				group: 'Core' with: #('XML-Parser');
				group: 'Tests' with: #('XML-Tests-Parser') ].

	"load gemstone methods"
	spec
		for: #'gemstone'
		do: [
			spec
				package: 'XML-Parser'
				with: [ spec includes: 'XML-Parser-GemstoneCompatibility' ].
			spec
				package: 'XML-Parser-GemstoneCompatibility'
				with: [ spec requires: 'XML-Parser' ]. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 11/26/2014 22:51'!
baseline183: spec 
        <version: '1.8.3-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.4.6'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/2/2014 06:08'!
baseline187: spec 
        <version: '1.8.7-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.4.7'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/6/2014 17:19'!
baseline188: spec 
        <version: '1.8.8-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.4.8'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/15/2014 15:57'!
baseline191: spec 
        <version: '1.9.1-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.4.8'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.1'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/16/2014 11:51'!
baseline193: spec 
        <version: '1.9.3-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.4.8'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.2'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/16/2014 19:43'!
baseline194: spec 
        <version: '1.9.4-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.2'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.3'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/18/2014 18:35'!
baseline196: spec 
        <version: '1.9.6-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.2'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.4'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 12/29/2014 01:26'!
baseline198: spec 
        <version: '1.9.8-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.2'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.5'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 1/7/2015 03:57'!
baseline200: spec 
        <version: '2.0.0-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.3'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.6'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 1/12/2015 00:15'!
baseline201: spec 
        <version: '2.0.1-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.4'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.6'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 2/11/2015 05:52'!
baseline205: spec 
        <version: '2.0.5-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.4'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.7'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 3/22/2015 06:01'!
baseline213: spec 
        <version: '2.1.3-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.5'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.7'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 3/24/2015 20:05'!
baseline216: spec 
        <version: '2.1.6-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.6'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.8'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 4/6/2015 07:32'!
baseline221: spec 
        <version: '2.2.1-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.6'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.9'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 4/19/2015 15:50'!
baseline231: spec 
        <version: '2.3.1-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.6'.

					"requires concrete versions from now on"
                spec project: 'BitmapCharacterSet' with: '1.1.5'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.10'. ].! !

!ConfigurationOfXMLParser methodsFor: 'baselines' stamp: 'monty 5/7/2015 19:09'!
baseline239: spec 
        <version: '2.3.9-baseline' imports: #('1.0-baseline')>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec project: 'XMLWriter' with: '2.5.9'.
                spec project: 'BitmapCharacterSet' with: '1.1.5'. ].

        spec for: #gemstone do: [
                spec
                    package: 'XML-Parser-GemstoneCompatibility'
                    with: 'XML-Parser-GemstoneCompatibility-monty.10'. ].! !

!ConfigurationOfXMLParser methodsFor: 'symbolic versions' stamp: 'monty 5/7/2015 19:10'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '2.3.9-baseline'.
! !

!ConfigurationOfXMLParser methodsFor: 'accessing' stamp: 'DaleHenrichs 2/7/2010 09:39'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfXMLParser methodsFor: 'symbolic versions' stamp: 'monty 5/7/2015 23:12'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '2.4.0'.! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'StephaneDucasse 3/2/2013 21:09'!
version100: spec
	<version: '1.0' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-NorbertHartl.141';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-JAA.14' 
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'SD 3/3/2013 10:45'!
version101: spec
	<version: '1.1' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-StephaneDucasse.142';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-StephaneDucasse.15' 
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'DamienCassou 4/30/2013 17:53'!
version102: spec
	<version: '1.2' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-DamienCassou.143';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-StephaneDucasse.15' 
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'StephaneDucasse 11/24/2013 18:31'!
version130: spec
	<version: '1.3' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec description: 'Enhancements made by Monty. These updates add validation against internal and external DTDs, proper replacement of general and parameter entites, customizable resolution of external parsed entities using Zinc and FileSystem, awareness of notations and unparsed entities, preservation of the internal DTD subset by the DOM parser (so printing a parsed doc with a DTD will produce approximately what was input), line numbers reporting in error messages, and better well-formed and validity constraints.

I had to largely rewrite the tokenizer to make everything work, but I followed the spec closely, and it is about the same speed as long as there is no DTD to validate against.'.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.184';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.28' 
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/26/2013 19:16'!
version131: spec
	<version: '1.3.1' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.186';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.29' 
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/28/2013 22:35'!
version132: spec
	<version: '1.3.2' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.187';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.29' 
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/1/2013 13:38'!
version133: spec
	<version: '1.3.3' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.189';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.31'
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/1/2013 22:56'!
version134: spec
	<version: '1.3.4' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.190';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.31'
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/8/2013 03:54'!
version135: spec
	<version: '1.3.5' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.191';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.33'
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/8/2013 04:45'!
version136: spec
	<version: '1.3.6' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.192';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.33'
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/9/2013 18:17'!
version137: spec
	<version: '1.3.7' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.193';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.34'
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/10/2013 06:55'!
version138: spec
	<version: '1.3.8' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.195';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.36'
				].
	
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/11/2013 03:05'!
version139: spec
	<version: '1.3.9' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.196';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.36'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/12/2013 03:11'!
version140: spec
	<version: '1.4.0' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.197';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.37'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/13/2013 05:39'!
version141: spec
	<version: '1.4.1' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.198';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.38'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/14/2013 03:03'!
version142: spec
	<version: '1.4.2' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.200';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.39'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/19/2013 02:02'!
version143: spec
	<version: '1.4.3' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.201';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.40'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/19/2013 08:12'!
version144: spec
	<version: '1.4.4' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.203';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.41'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/22/2013 06:44'!
version145: spec
	<version: '1.4.5' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.205';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.43'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'StephaneDucasse 12/27/2013 17:15'!
version146: spec
	<version: '1.4.6' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.205';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-StephaneDucasse.44'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/29/2013 03:26'!
version147: spec
	<version: '1.4.7' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.208';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.46'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/31/2013 03:18'!
version148: spec
	<version: '1.4.8' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.210';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.47'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/1/2014 07:34'!
version149: spec
	<version: '1.4.9' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.211';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.47'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/4/2014 08:21'!
version150: spec
	<version: '1.5.0' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.213';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.48'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/5/2014 19:12'!
version151: spec
	<version: '1.5.1' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.215';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.48'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/14/2014 02:32'!
version152: spec
	<version: '1.5.2' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.216';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.49'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/24/2014 23:48'!
version153: spec
	<version: '1.5.3' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.218';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.51'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/25/2014 05:07'!
version154: spec
	<version: '1.5.4' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.219';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.52'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/26/2014 04:36'!
version155: spec
	<version: '1.5.5' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.220';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.53'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/3/2014 01:24'!
version156: spec
	<version: '1.5.6' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.221';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.54'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/4/2014 03:01'!
version157: spec
	<version: '1.5.7' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.222';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.55'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/6/2014 20:12'!
version158: spec
	<version: '1.5.8' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.223';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.56'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/8/2014 03:18'!
version159: spec
	<version: '1.5.9' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.224';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.56'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/11/2014 02:41'!
version160: spec
	<version: '1.6.0' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.225';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.57'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/15/2014 04:03'!
version161: spec
	<version: '1.6.1' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.226';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.58'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/18/2014 02:51'!
version162: spec
	<version: '1.6.2' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.227';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.58'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/20/2014 03:21'!
version163: spec
	<version: '1.6.3' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.228';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.58'
				].
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'DiegoLont 5/21/2014 14:35'!
version164: spec
	<version: '1.6.4' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				description: 'Added a pharo2 specific method to fix tests'.
			spec
				package: 'XML-Parser' with: 'XML-Parser-monty.228';
				package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.58' ].
	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version165: spec
	<version: '1.6.5' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec description: 'version 1.6.5'.
		spec author: 'GuillaumeLarcheveque'.
		spec timestamp: '6/27/2014 16:14'.
		spec 
			project: 'XMLWriter' with: '2.3.10';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.228';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.58'. ].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version166: spec
	<version: '1.6.6' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec description: 'version 1.6.6'.
		spec 
			project: 'XMLWriter' with: '2.3.10';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.229';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.60'. ].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version167: spec
	<version: '1.6.7' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec description: 'version 1.6.7'.
		spec 
			project: 'XMLWriter' with: '2.3.10';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.230';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.60'. ].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version168: spec
	<version: '1.6.8' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec description: 'version 1.6.8'.
		spec 
			project: 'XMLWriter' with: '2.3.10';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.231';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.60'. ].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version169: spec
	<version: '1.6.9' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.3.10';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.234';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.62'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version170: spec
	<version: '1.7.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.1';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.235';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.63'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version171: spec
	<version: '1.7.1' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.1';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2.1'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.236';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.64'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version172: spec
	<version: '1.7.2' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.1';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2.1'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.237';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.65'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version173: spec
	<version: '1.7.3' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.1';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2.3'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.238';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.66'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version174: spec
	<version: '1.7.4' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.1';
			project: 'BitmapCharacterSet' with: '1.1';
			project: 'OrderPreservingDictionary' with: '1.2.3'.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-monty.240';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.68'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version175: spec
	<version: '1.7.5' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.2';
			package: 'XML-Parser' with: 'XML-Parser-monty.241';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.69'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version176: spec
	<version: '1.7.6' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.3';
			package: 'XML-Parser' with: 'XML-Parser-monty.242';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.70'.].

	spec for: #'pharo2.x'
		do: [ 
			spec package: 'XML-Pharo2-Parser' with: 'XML-Pharo2-Parser-DiegoLont.1' ]
	
! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/7/2014 16:31'!
version177: spec
	<version: '1.7.7' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #release.
		spec 
			project: 'XMLWriter' with: '2.4.3';
			package: 'XML-Parser' with: 'XML-Parser-monty.243';
			package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.71'.]! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/6/2014 18:40'!
version178: spec 
        <version: '1.7.8' imports: #('1.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec project: 'XMLWriter' with: '2.4.4'.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.244'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.72'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/7/2014 02:21'!
version179: spec 
        <version: '1.7.9' imports: #('1.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec project: 'XMLWriter' with: '2.4.4'.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.245'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.73'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/7/2014 19:24'!
version180: spec 
        <version: '1.8.0' imports: #('1.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec project: 'XMLWriter' with: '2.4.4'.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.246'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.74'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/20/2014 04:27'!
version181: spec 
        <version: '1.8.1' imports: #('1.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec project: 'XMLWriter' with: '2.4.4'.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.247'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.75'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/22/2014 01:16'!
version182: spec 
        <version: '1.8.2' imports: #('1.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec project: 'XMLWriter' with: '2.4.5'.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.248'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.76'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/26/2014 22:34'!
version183: spec 
        <version: '1.8.3' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.250'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.77'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/26/2014 22:35'!
version184: spec 
        <version: '1.8.4' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.251'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.78'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/26/2014 22:35'!
version185: spec 
        <version: '1.8.5' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.252'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.79'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 11/28/2014 11:32'!
version186: spec 
        <version: '1.8.6' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.253'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.80'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/2/2014 06:09'!
version187: spec 
        <version: '1.8.7' imports: #('1.8.7-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.254'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.81'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/6/2014 17:18'!
version188: spec 
        <version: '1.8.8' imports: #('1.8.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.255'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.82'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/11/2014 10:39'!
version189: spec 
        <version: '1.8.9' imports: #('1.8.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.257'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.83'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/12/2014 08:52'!
version190: spec 
        <version: '1.9.0' imports: #('1.8.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.258'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.83'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/14/2014 22:41'!
version191: spec 
        <version: '1.9.1' imports: #('1.9.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.259'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.84'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/15/2014 17:11'!
version192: spec 
        <version: '1.9.2' imports: #('1.9.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.259'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.85'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/16/2014 11:57'!
version193: spec 
        <version: '1.9.3' imports: #('1.9.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.260'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.86'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/16/2014 16:18'!
version194: spec 
        <version: '1.9.4' imports: #('1.9.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.261'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.86'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/16/2014 20:37'!
version195: spec 
        <version: '1.9.5' imports: #('1.9.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.262'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.86'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/18/2014 19:46'!
version196: spec 
        <version: '1.9.6' imports: #('1.9.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.263'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.86'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/23/2014 21:24'!
version197: spec 
        <version: '1.9.7' imports: #('1.9.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.264'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.87'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/29/2014 01:27'!
version198: spec 
        <version: '1.9.8' imports: #('1.9.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.265'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.88'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 12/29/2014 21:03'!
version199: spec 
        <version: '1.9.9' imports: #('1.9.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.266'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.89'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/7/2015 03:58'!
version200: spec 
        <version: '2.0.0' imports: #('2.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.268'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.91'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/12/2015 00:58'!
version201: spec 
        <version: '2.0.1' imports: #('2.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.269'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.91'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/18/2015 19:08'!
version202: spec 
        <version: '2.0.2' imports: #('2.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.270'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.92'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/21/2015 16:10'!
version203: spec 
        <version: '2.0.3' imports: #('2.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.271'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.93'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 1/30/2015 20:38'!
version204: spec 
        <version: '2.0.4' imports: #('2.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.272'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.94'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/11/2015 05:52'!
version205: spec 
        <version: '2.0.5' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.273'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.95'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 2/13/2015 22:27'!
version206: spec 
        <version: '2.0.6' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.274'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.96'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/2/2015 13:16'!
version207: spec 
        <version: '2.0.7' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.275'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.97'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/3/2015 08:22'!
version208: spec 
        <version: '2.0.8' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.275'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.98'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/9/2015 19:16'!
version209: spec 
        <version: '2.0.9' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.276'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.99'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/12/2015 18:36'!
version210: spec 
        <version: '2.1.0' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.277'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.100'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/13/2015 20:46'!
version211: spec 
        <version: '2.1.1' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.278'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.100'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/17/2015 18:49'!
version212: spec 
        <version: '2.1.2' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.279'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.100'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/22/2015 06:01'!
version213: spec 
        <version: '2.1.3' imports: #('2.1.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.280'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.103'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/22/2015 17:40'!
version214: spec 
        <version: '2.1.4' imports: #('2.1.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.281'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.104'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/24/2015 18:42'!
version215: spec 
        <version: '2.1.5' imports: #('2.1.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.282'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.105'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/24/2015 20:08'!
version216: spec 
        <version: '2.1.6' imports: #('2.1.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.283'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.105'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/24/2015 20:57'!
version217: spec 
        <version: '2.1.7' imports: #('2.1.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.284'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.106'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 3/25/2015 18:30'!
version218: spec 
        <version: '2.1.8' imports: #('2.1.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.285'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.106'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/1/2015 19:13'!
version219: spec 
        <version: '2.1.9' imports: #('2.1.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.286'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.107'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/3/2015 04:46'!
version220: spec 
        <version: '2.2.0' imports: #('2.1.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.287'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.108'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/6/2015 09:33'!
version221: spec 
        <version: '2.2.1' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.288'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.109'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/6/2015 10:50'!
version222: spec 
        <version: '2.2.2' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.290'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.109'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/7/2015 00:14'!
version223: spec 
        <version: '2.2.3' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.291'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.110'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/7/2015 06:12'!
version224: spec 
        <version: '2.2.4' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.292'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.111'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/7/2015 09:32'!
version225: spec 
        <version: '2.2.5' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.293'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.112'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/11/2015 03:18'!
version226: spec 
        <version: '2.2.6' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.294'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.113'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/11/2015 08:06'!
version227: spec 
        <version: '2.2.7' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.295'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.114'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/13/2015 03:31'!
version228: spec 
        <version: '2.2.8' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.296'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.115'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/15/2015 03:14'!
version229: spec 
        <version: '2.2.9' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.298'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.115'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/16/2015 01:15'!
version230: spec 
        <version: '2.3.0' imports: #('2.2.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.299'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.115'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/18/2015 10:02'!
version231: spec 
        <version: '2.3.1' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.300'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.116'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/19/2015 16:02'!
version232: spec 
        <version: '2.3.2' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.300'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.117'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/21/2015 14:29'!
version233: spec 
        <version: '2.3.3' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.301'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.118'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/22/2015 15:52'!
version234: spec 
        <version: '2.3.4' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.302'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.119'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/23/2015 20:52'!
version235: spec 
        <version: '2.3.5' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.303'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.120'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/27/2015 00:19'!
version236: spec 
        <version: '2.3.6' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.304'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.121'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 4/28/2015 19:03'!
version237: spec 
        <version: '2.3.7' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.305'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.121'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 5/3/2015 19:43'!
version238: spec 
        <version: '2.3.8' imports: #('2.3.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.306'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.122'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 5/7/2015 19:19'!
version239: spec 
        <version: '2.3.9' imports: #('2.3.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.307'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.122'.
                ].! !

!ConfigurationOfXMLParser methodsFor: 'versions' stamp: 'monty 5/7/2015 23:12'!
version240: spec 
        <version: '2.4.0' imports: #('2.3.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XML-Parser' with: 'XML-Parser-monty.308'.
			spec package: 'XML-Tests-Parser' with: 'XML-Tests-Parser-monty.123'.
                ].! !
